=====
mcrpc
=====

|status| |license|

.. |status| image:: https://img.shields.io/pypi/v/mcrpc.svg
   :target: https://pypi.python.org/pypi/mcrpc/
   :alt: PyPI Status
.. |license| image:: https://img.shields.io/pypi/l/mcrpc.svg
   :target: https://pypi.python.org/pypi/mcrpc/
   :alt: PyPI License


Content Blockchain RPC Client
=============================

A Python 3 MultiChain RPC client build for the `Content Blockchain Project <https://content-blockchain.org/>`_

This client is build against the API of the latest v2.0 alpha build of `MultiChain <https://www.multichain.com/developers/multichain-2-0-preview-releases/>`_ and includes code generated function annotations and api documentation to support code completion and get you up to speed fast.


Code Completion
---------------

.. figure:: https://raw.githubusercontent.com/coblo/mcrpc/master/images/mcrpc_cc.png
   :align: center
   :alt: mcrpc code completaion


Code Documentation
------------------

.. figure:: https://raw.githubusercontent.com/coblo/mcrpc/master/images/mcrpc_doc.png
   :align: center
   :alt: mcrpc documentation


Installing
==========

The RPC client is published with the package name `mcrpc <https://pypi.python.org/pypi/mcrpc>`_ on Python Package Index. Install it with:

.. code-block:: bash

    pip install mcrpc


* Free software: GNU General Public License v3
